@@ -30,8 +30,16 @@ class PCIDevice(Device):
 	@property
 	def deviceclass(self):
 		return self._uevent['PCI_CLASS']
-	
-	
+
+	@property
+	def sub_vendor(self):
+		return self._uevent["PCI_SUBSYS_ID"].split(":")[0]
+
+	@property
+	def sub_model(self):
+		return self._uevent["PCI_SUBSYS_ID"].split(":")[1]
+
+
 class USBDevice(Device):
 	subsystem = "usb"
 	
