@@ -209,10 +209,12 @@ class System(object):
 
 		ids = _ids
 
-		# Use serial number from root disk (if available)
-		root_disk_serial = self.root_disk_serial
-		if root_disk_serial:
-			ids.append(root_disk_serial)
+		# Use serial number from root disk (if available) and if
+		# no other ID was found, yet.
+		if not ids:
+			root_disk_serial = self.root_disk_serial
+			if root_disk_serial:
+				ids.append(root_disk_serial)
 
 		# As last resort, we use the UUID from pakfire.
 		if not ids:
@@ -303,6 +305,9 @@ class System(object):
 		toscan = (("/sys/bus/pci/devices", device.PCIDevice),
 		("/sys/bus/usb/devices", device.USBDevice))
 		for path, cls in toscan:
+			if not os.path.exists(path):
+				continue
+
 			dirlist = os.listdir(path)
 			for dir in dirlist:
 				self.devices.append(cls(os.path.join(path, dir)))
